diff --git a/lisp/org.el b/lisp/org.el
index 2cfe466..261d5ed 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -1897,6 +1897,28 @@ You can interactively set the value of this variable by calling
   :group 'org-link
   :type 'boolean)
 
+(defcustom org-link-brackets '(0 0)
+  "Number of bracket pairs shown while `org-descriptive-links' is t.
+
+The first element is for descriptive links and can be 0 or 1. The
+second element is for non-descriptive links and can be 0, 1 or 2.
+
+Value examples:
+
+'(1 1) can be useful for a better navigation and editing
+experience at the beginning and end of a link.
+
+'(0 2) can be useful to get the same table alignment and
+paragraph filling for non-descriptive links as in Org also in
+non-Org tools. For descriptive links this is not possible,
+therefore in this example the default 0."
+
+  ;; TODO: Type and value check for customization.
+  ;; TODO: Just a list was simple for a first step but is possibly not
+  ;; state of the art for such a config.
+
+  :group 'org-link)
+
 (defcustom org-link-file-path-type 'adaptive
   "How the path name in file links should be stored.
 Valid values are:
@@ -5914,8 +5936,19 @@ This includes angle, plain, and bracket links."
 			       ,(or (org-link-get-parameter type :display)
 				    'org-link))
 			     properties))
-		    (visible-start (or (match-beginning 4) (match-beginning 2)))
-		    (visible-end (or (match-end 4) (match-end 2))))
+		    (visible-start
+		     (or
+		      ;; For descriptive links.
+		      (match-beginning
+		       (if (zerop (car org-link-brackets)) 4 3))
+		      ;; For non-descriptive links.
+		      (- (match-beginning 2) (cadr org-link-brackets))))
+		    (visible-end
+		     (or
+		      ;; For descriptive links.
+		      (match-end (if (zerop (car org-link-brackets)) 4 3))
+		      ;; For non-descriptive links.
+		      (+ (match-end 2) (cadr org-link-brackets)))))
 		(add-text-properties start visible-start hidden)
 		(add-text-properties visible-start visible-end properties)
 		(add-text-properties visible-end end hidden)
